Fakturierung — Lino Tera Benutzerhandbuch

# Fakturierung

- Automatikfakturierung

- Manuelle Verkaufsrechnungen

## Automatikfakturierung

Checkliste:

- Haben alle Therapeuten ihre Kassenrolle für den vergangenen Monat eingereicht?

Anweisungen:

- Wähle Verkauf ‣ Rechnungen erstellen und fülle alle Felder wie folgt aus:

  > - Autor : wer als Autor der erstellten Rechnungen vermerkt sein wird. NB Dies erscheint nicht auf den Rechnungen selber.

  > - Journal : in welchem Journal die Rechnungen erstellt werden sollen

  > - Heute : auf welches Datum die Rechnungen datiert werden sollen

  > - Fakturierbare bis : bis zu welchem Datum fakturiert werden soll.

  > - Partner : wenn nicht leer, dann nur Rechnungen an diesen Empfänger generieren

  > - Akte : wenn nicht leer, dann nur Rechnung für diese Akte erstellen.

- Klicke auf den gelben Blitz (), um Vorschläge generieren zu lassen.

## Manuelle Verkaufsrechnungen

Abgesehen von den automatisch erstellten Rechnungen kannst Du jederzeit auch manuell Verkaufsrechnungen (VKR) erstellen und ausdrucken. Manuelle VKR stehen üblicherweise in einem eigenen Journal, um sie nicht mit den automatisch erstellten VKR zu vermischen.

Um eine neue VKR zu erfassen, wähle im Hauptmenü :menuselection:` Buchhaltung –> Verkauf –> (gewünschtes Journal)` und klicke dann auf um eine neue Rechnung einzufügen.

Anders als bei Einkaufsrechnungen gibst Du in VKR keinen Gesamtbetrag ein und wählst einen „Tarif“ statt eines Generalkontos. Ansonsten ist die Bedienung ähnlich.